==> zio-aws-wafregional_3-5.17.126.2-sources.jar: zio/aws/wafregional/model/ListGeoMatchSetsRequest.scala <==
package zio.aws.wafregional.model
import java.lang.Integer
import zio.aws.wafregional.model.primitives.{PaginationLimit, NextMarker}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListGeoMatchSetsRequest(
    nextMarker: Option[NextMarker] = None,
    limit: Option[PaginationLimit] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest = {
    import ListGeoMatchSetsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        limit.map(value => PaginationLimit.unwrap(value): Integer)
      )(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly =
    zio.aws.wafregional.model.ListGeoMatchSetsRequest.wrap(buildAwsValue())
}
object ListGeoMatchSetsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListGeoMatchSetsRequest =
      zio.aws.wafregional.model.ListGeoMatchSetsRequest(
        nextMarker.map(value => value),
        limit.map(value => value)
      )
    def nextMarker: Option[NextMarker]
    def limit: Option[PaginationLimit]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getLimit: ZIO[Any, AwsError, PaginationLimit] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ) extends zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val limit: Option[PaginationLimit] = scala
      .Option(impl.limit())
      .map(value => zio.aws.wafregional.model.primitives.PaginationLimit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ): zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-wafregional_3-6.20.74.1-sources.jar: zio/aws/wafregional/model/ListGeoMatchSetsRequest.scala <==
package zio.aws.wafregional.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.wafregional.model.primitives.{PaginationLimit, NextMarker}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ListGeoMatchSetsRequest(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    limit: Optional[PaginationLimit] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest = {
    import ListGeoMatchSetsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(
        limit.map(value => PaginationLimit.unwrap(value): Integer)
      )(_.limit)
      .build()
  }
  def asReadOnly: zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly =
    zio.aws.wafregional.model.ListGeoMatchSetsRequest.wrap(buildAwsValue())
}
object ListGeoMatchSetsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.wafregional.model.ListGeoMatchSetsRequest =
      zio.aws.wafregional.model.ListGeoMatchSetsRequest(
        nextMarker.map(value => value),
        limit.map(value => value)
      )
    def nextMarker: Optional[NextMarker]
    def limit: Optional[PaginationLimit]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getLimit: ZIO[Any, AwsError, PaginationLimit] =
      AwsError.unwrapOptionField("limit", limit)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ) extends zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.wafregional.model.primitives.NextMarker(value))
    override val limit: Optional[PaginationLimit] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => zio.aws.wafregional.model.primitives.PaginationLimit(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListGeoMatchSetsRequest
  ): zio.aws.wafregional.model.ListGeoMatchSetsRequest.ReadOnly = new Wrapper(
    impl
  )
}
